@@ -3,10 +3,10 @@ use proc_macro::TokenStream;
 mod common;
 mod debug_lisp;
 mod lexer;
-mod parse;
+mod regex;
 mod token;
 
-#[proc_macro_derive(Token, attributes(pattern))]
+#[proc_macro_derive(Token, attributes(pattern, subset_of))]
 pub fn derive_token(input: TokenStream) -> TokenStream {
 	token::derive(input)
 }
@@ -16,11 +16,6 @@ pub fn derive_lexer(input: TokenStream) -> TokenStream {
 	lexer::derive(input)
 }
 
-#[proc_macro_derive(Parse, attributes(parse_token, token, token_kind))]
-pub fn derive_parse(input: TokenStream) -> TokenStream {
-	parse::derive(input)
-}
-
 #[proc_macro_derive(DebugLisp)]
 pub fn derive_debug_lisp(input: TokenStream) -> TokenStream {
 	debug_lisp::derive(input)
@@ -30,3 +25,8 @@ pub fn derive_debug_lisp(input: TokenStream) -> TokenStream {
 pub fn derive_debug_lisp_token(input: TokenStream) -> TokenStream {
 	debug_lisp::derive_token(input)
 }
+
+#[proc_macro]
+pub fn regex(input: TokenStream) -> TokenStream {
+	regex::proc(input)
+}
